[mapguide-commits] r10019 - in trunk/MgDev: Bindings/src/Managed/DotNet/Common Bindings/src/Managed/DotNet/OSGeo.MapGuide.Portable Bindings/src/Tools/ClassMapGen Portable/MgPortable/MapLayer Portable/MgPortable/Services Portable/MgPortable/Services/Rendering Portable/MgPortable/System

svn_mapguide at osgeo.org svn_mapguide at osgeo.org
Sat Nov 19 20:09:42 PST 2022


Author: jng
Date: 2022-11-19 20:09:40 -0800 (Sat, 19 Nov 2022)
New Revision: 10019

Modified:
   trunk/MgDev/Bindings/src/Managed/DotNet/Common/MgClassMap.cs
   trunk/MgDev/Bindings/src/Managed/DotNet/OSGeo.MapGuide.Portable/OSGeo.MapGuide.Portable.csproj
   trunk/MgDev/Bindings/src/Tools/ClassMapGen/Program.cs
   trunk/MgDev/Bindings/src/Tools/ClassMapGen/classids.i
   trunk/MgDev/Portable/MgPortable/MapLayer/Layer.h
   trunk/MgDev/Portable/MgPortable/MapLayer/Map.h
   trunk/MgDev/Portable/MgPortable/MapLayer/Selection.h
   trunk/MgDev/Portable/MgPortable/Services/DrawingService.h
   trunk/MgDev/Portable/MgPortable/Services/FeatureService.h
   trunk/MgDev/Portable/MgPortable/Services/MappingService.h
   trunk/MgDev/Portable/MgPortable/Services/ProfilingService.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/DwfVersion.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/FeatureInformation.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/Layout.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlot.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlotCollection.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/PlotSpecification.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/PrintLayout.h
   trunk/MgDev/Portable/MgPortable/Services/Rendering/RenderingOptions.h
   trunk/MgDev/Portable/MgPortable/Services/RenderingService.h
   trunk/MgDev/Portable/MgPortable/Services/ResourceService.h
   trunk/MgDev/Portable/MgPortable/Services/ServiceFactory.h
   trunk/MgDev/Portable/MgPortable/Services/TileService.h
   trunk/MgDev/Portable/MgPortable/System/ClassId.h
   trunk/MgDev/Portable/MgPortable/System/PlatformInit.cpp
Log:
#2852: MgPortable build changes
 
 - Update ClassMapGen to also process MgPortable headers
 - Rework MgPortable class ids to:
   a) Not collide with class ids ranges already in the core MapGuide API
   b) Fix the symbolic naming convention to match the core MapGuide API counterparts and for it to be easily parseable by ClassMapGen

Modified: trunk/MgDev/Bindings/src/Managed/DotNet/Common/MgClassMap.cs
===================================================================
--- trunk/MgDev/Bindings/src/Managed/DotNet/Common/MgClassMap.cs	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Bindings/src/Managed/DotNet/Common/MgClassMap.cs	2022-11-20 04:09:40 UTC (rev 10019)
@@ -260,6 +260,30 @@
                 classIdCtorMap[40005] = TryResolveConstructor("OSGeo.MapGuide.MgHttpResponse");
                 classIdCtorMap[40006] = TryResolveConstructor("OSGeo.MapGuide.MgHttpPrimitiveValue");
             }
+#if MG_PORTABLE_API
+            if (HasAssemblyInAppDomain("OSGeo.MapGuide.Portable")) {
+                classIdCtorMap[60500] = TryResolveConstructor("OSGeo.MapGuide.MgPortableMap");
+                classIdCtorMap[60501] = TryResolveConstructor("OSGeo.MapGuide.MgPortableLayer");
+                classIdCtorMap[60502] = TryResolveConstructor("OSGeo.MapGuide.MgPortableSelection");
+                classIdCtorMap[60600] = TryResolveConstructor("OSGeo.MapGuide.MgPortableServiceFactory");
+                classIdCtorMap[60800] = TryResolveConstructor("OSGeo.MapGuide.MgPortableFeatureService");
+                classIdCtorMap[60700] = TryResolveConstructor("OSGeo.MapGuide.MgPortableDrawingService");
+                classIdCtorMap[60900] = TryResolveConstructor("OSGeo.MapGuide.MgPortableMappingService");
+                classIdCtorMap[60901] = TryResolveConstructor("OSGeo.MapGuide.MgPortableDwfVersion");
+                classIdCtorMap[60902] = TryResolveConstructor("OSGeo.MapGuide.MgPortablePlotSpecification");
+                classIdCtorMap[60903] = TryResolveConstructor("OSGeo.MapGuide.MgPortablePrintLayout");
+                classIdCtorMap[60904] = TryResolveConstructor("OSGeo.MapGuide.MgPortableLayout");
+                classIdCtorMap[60905] = TryResolveConstructor("OSGeo.MapGuide.MgPortableMapPlot");
+                classIdCtorMap[60906] = TryResolveConstructor("OSGeo.MapGuide.MgPortableMapPlotCollection");
+                classIdCtorMap[61000] = TryResolveConstructor("OSGeo.MapGuide.MgPortableRenderingService");
+                classIdCtorMap[61001] = TryResolveConstructor("OSGeo.MapGuide.MgPortableFeatureInformation");
+                classIdCtorMap[61002] = TryResolveConstructor("OSGeo.MapGuide.MgPortableRenderingOptions");
+                classIdCtorMap[61100] = TryResolveConstructor("OSGeo.MapGuide.MgPortableResourceService");
+                classIdCtorMap[61200] = TryResolveConstructor("OSGeo.MapGuide.MgPortableTileService");
+                classIdCtorMap[61300] = TryResolveConstructor("OSGeo.MapGuide.MgPortableKmlService");
+                classIdCtorMap[61400] = TryResolveConstructor("OSGeo.MapGuide.MgPortableProfilingService");
+            }
+#endif
 
 
             //Sanity check that we haven't double registered the same type name under different

Modified: trunk/MgDev/Bindings/src/Managed/DotNet/OSGeo.MapGuide.Portable/OSGeo.MapGuide.Portable.csproj
===================================================================
--- trunk/MgDev/Bindings/src/Managed/DotNet/OSGeo.MapGuide.Portable/OSGeo.MapGuide.Portable.csproj	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Bindings/src/Managed/DotNet/OSGeo.MapGuide.Portable/OSGeo.MapGuide.Portable.csproj	2022-11-20 04:09:40 UTC (rev 10019)
@@ -20,10 +20,12 @@
   <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|AnyCPU'">
     <OutputPath>..\..\..\..\..\packages\DotNet\Release</OutputPath>
     <DocumentationFile>..\..\..\..\..\packages\DotNet\Release\OSGeo.MapGuide.Portable.xml</DocumentationFile>
+    <DefineConstants>$(DefineConstants);MG_PORTABLE_API</DefineConstants>
   </PropertyGroup>
 
   <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|AnyCPU'">
     <OutputPath>..\..\..\..\..\packages\DotNet\Debug</OutputPath>
+    <DefineConstants>$(DefineConstants);MG_PORTABLE_API</DefineConstants>
   </PropertyGroup>
 
   <ItemGroup>

Modified: trunk/MgDev/Bindings/src/Tools/ClassMapGen/Program.cs
===================================================================
--- trunk/MgDev/Bindings/src/Tools/ClassMapGen/classids.i	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Bindings/src/Tools/ClassMapGen/classids.i	2022-11-20 04:09:40 UTC (rev 10019)
@@ -3,4 +3,5 @@
 %include "./../../../../Common/PlatformBase/Services/PlatformBaseClassId.h"
 %include "./../../../../Common/MapGuideCommon/System/MapGuideCommonClassId.h"
 %include "./../../../../Web/src/WebApp/WebAppClassId.h"
-%include "./../../../../Web/src/HttpHandler/HttpHandlerClassId.h"
\ No newline at end of file
+%include "./../../../../Web/src/HttpHandler/HttpHandlerClassId.h"
+%include "./../../../../Portable/MgPortable/System/ClassId.h"
\ No newline at end of file

Modified: trunk/MgDev/Portable/MgPortable/MapLayer/Layer.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/MapLayer/Layer.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/MapLayer/Layer.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -392,7 +392,7 @@
     }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MapLayer_Layer;
+    static const INT32 m_cls_id = Portable_MapLayer_Layer;
 };
 /// \}
 #endif
\ No newline at end of file

Modified: trunk/MgDev/Portable/MgPortable/MapLayer/Map.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/MapLayer/Map.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/MapLayer/Map.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -128,7 +128,7 @@
     void InitializeResourceService(MgResourceService* resourceService);
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MapLayer_Map;
+    static const INT32 m_cls_id = Portable_MapLayer_Map;
 
 private:
 

Modified: trunk/MgDev/Portable/MgPortable/MapLayer/Selection.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/MapLayer/Selection.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/MapLayer/Selection.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -62,7 +62,7 @@
     STRING GetResourceName(CREFSTRING sessionId, CREFSTRING mapName);
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MapLayer_Selection;
+    static const INT32 m_cls_id = Portable_MapLayer_Selection;
 };
 /// \}
 #endif
\ No newline at end of file

Modified: trunk/MgDev/Portable/MgPortable/Services/DrawingService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/DrawingService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/DrawingService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -386,7 +386,7 @@
     virtual STRING GetCoordinateSpace(MgResourceIdentifier* resource);
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_DrawingService_DrawingService;
+    static const INT32 m_cls_id = Portable_DrawingService_DrawingService;
 
 protected:
     virtual INT32 GetClassId() { return m_cls_id; }

Modified: trunk/MgDev/Portable/MgPortable/Services/FeatureService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/FeatureService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/FeatureService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -264,7 +264,7 @@
                                              INT32 fetchSize);
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_FeatureService_FeatureService;
+    static const INT32 m_cls_id = Portable_FeatureService_FeatureService;
 
 protected:
     virtual INT32 GetClassId() { return m_cls_id; }

Modified: trunk/MgDev/Portable/MgPortable/Services/MappingService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/MappingService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/MappingService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -228,7 +228,7 @@
     virtual void Dispose() { delete this; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_RenderingService_RenderingService;
+    static const INT32 m_cls_id = Portable_RenderingService_RenderingService;
 };
 /// \}
 #endif
\ No newline at end of file

Modified: trunk/MgDev/Portable/MgPortable/Services/ProfilingService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/ProfilingService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/ProfilingService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -120,7 +120,7 @@
     MgPortableRenderingService* m_svcRendering;
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_ProfilingService_ProfilingService;
+    static const INT32 m_cls_id = Portable_ProfilingService_ProfilingService;
 };
 /// \}
 

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/DwfVersion.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/DwfVersion.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/DwfVersion.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -180,7 +180,7 @@
     virtual INT32 GetClassId() { return m_cls_id; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_DwfVersion;
+    static const INT32 m_cls_id = Portable_MappingService_DwfVersion;
 
 INTERNAL_API:
     //////////////////////////////////////////////////////////////////

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/FeatureInformation.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/FeatureInformation.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/FeatureInformation.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -168,7 +168,7 @@
     virtual INT32 GetClassId() { return m_cls_id; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_RenderingService_FeatureInformation;
+    static const INT32 m_cls_id = Portable_RenderingService_FeatureInformation;
 
 protected:
 

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/Layout.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/Layout.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/Layout.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -224,7 +224,7 @@
     virtual INT32 GetClassId() { return m_cls_id; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_Layout;
+    static const INT32 m_cls_id = Portable_MappingService_Layout;
 
 INTERNAL_API:
 

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlot.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlot.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlot.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -498,7 +498,7 @@
     }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_MapPlot;
+    static const INT32 m_cls_id = Portable_MappingService_MapPlot;
 
 private:
 

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlotCollection.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlotCollection.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/MapPlotCollection.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -419,7 +419,7 @@
     }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_MapPlotCollection;
+    static const INT32 m_cls_id = Portable_MappingService_MapPlotCollection;
 
 private:
     MgNamedCollection*   m_mapPlots;

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/PlotSpecification.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/PlotSpecification.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/PlotSpecification.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -297,7 +297,7 @@
     virtual INT32 GetClassId() { return m_cls_id; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_PlotSpecification;
+    static const INT32 m_cls_id = Portable_MappingService_PlotSpecification;
 
 INTERNAL_API:
     //////////////////////////////////////////////////////////////////

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/PrintLayout.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/PrintLayout.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/PrintLayout.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -209,7 +209,7 @@
     }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_PrintLayout;
+    static const INT32 m_cls_id = Portable_MappingService_PrintLayout;
 
 INTERNAL_API:
     /// Layout element constants

Modified: trunk/MgDev/Portable/MgPortable/Services/Rendering/RenderingOptions.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/Rendering/RenderingOptions.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/Rendering/RenderingOptions.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -153,7 +153,7 @@
     INT32 m_behavior;
     Ptr<MgColor> m_selectionColor;
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_RenderingService_RenderingOptions;
+    static const INT32 m_cls_id = Portable_RenderingService_RenderingOptions;
 };
 /// \}
 

Modified: trunk/MgDev/Portable/MgPortable/Services/RenderingService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/RenderingService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/RenderingService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -549,7 +549,7 @@
     virtual void Dispose() { delete this; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_MappingService_MappingService;
+    static const INT32 m_cls_id = Portable_MappingService_MappingService;
 };
 /// \}
 #endif
\ No newline at end of file

Modified: trunk/MgDev/Portable/MgPortable/Services/ResourceService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/ResourceService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/ResourceService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -113,7 +113,7 @@
     void AddAliasMapping(CREFSTRING aliasName, CREFSTRING path);
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_ResourceService_ResourceService;
+    static const INT32 m_cls_id = Portable_ResourceService_ResourceService;
 
 protected:
     virtual INT32 GetClassId() { return m_cls_id; }

Modified: trunk/MgDev/Portable/MgPortable/Services/ServiceFactory.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/ServiceFactory.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/ServiceFactory.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -67,7 +67,7 @@
     static void Initialize();
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_ServiceFactory;
+    static const INT32 m_cls_id = Portable_Services_ServiceFactory;
 
 protected:
     ~MgPortableServiceFactory();

Modified: trunk/MgDev/Portable/MgPortable/Services/TileService.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/Services/TileService.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/Services/TileService.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -71,7 +71,7 @@
     virtual void Dispose() { delete this; }
 
 CLASS_ID:
-    static const INT32 m_cls_id = MapGuide_Portable_TileService_TileService;
+    static const INT32 m_cls_id = Portable_TileService_TileService;
 
 private:
 

Modified: trunk/MgDev/Portable/MgPortable/System/ClassId.h
===================================================================
--- trunk/MgDev/Portable/MgPortable/System/ClassId.h	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/System/ClassId.h	2022-11-20 04:09:40 UTC (rev 10019)
@@ -19,129 +19,120 @@
 #define PORTABLE_CLASSID_H
 
 // Predefined ranges for each service
-#define MAPGUIDE_PORTABLE_EXCEPTION_ID           40000
-#define MAPGUIDE_PORTABLE_MAPLAYER_ID            40500
-#define MAPGUIDE_PORTABLE_SERVICE_ID             40600
-#define MAPGUIDE_PORTABLE_DRAWINGSERVICE_ID      40700
-#define MAPGUIDE_PORTABLE_FEATURESERVICE_ID      40800
-#define MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID      40900
-#define MAPGUIDE_PORTABLE_RENDERINGSERVICE_ID    41000
-#define MAPGUIDE_PORTABLE_RESOURCESERVICE_ID     41100
-#define MAPGUIDE_PORTABLE_TILESERVICE_ID         41200
-#define MAPGUIDE_PORTABLE_KMLSERVICE_ID          41300
-#define MAPGUIDE_PORTABLE_PROFILING_SERVICE_ID   41400
+#define PORTABLE_EXCEPTION_ID           60000
+#define PORTABLE_MAPLAYER_ID            60500
+#define PORTABLE_SERVICE_ID             60600
+#define PORTABLE_DRAWINGSERVICE_ID      60700
+#define PORTABLE_FEATURESERVICE_ID      60800
+#define PORTABLE_MAPPINGSERVICE_ID      60900
+#define PORTABLE_RENDERINGSERVICE_ID    61000
+#define PORTABLE_RESOURCESERVICE_ID     61100
+#define PORTABLE_TILESERVICE_ID         61200
+#define PORTABLE_KMLSERVICE_ID          61300
+#define PORTABLE_PROFILING_SERVICE_ID   61400
 
 // MapLayer API
-#define MapGuide_Portable_MapLayer_Map           MAPGUIDE_PORTABLE_MAPLAYER_ID+0
-#define MapGuide_Portable_MapLayer_Layer         MAPGUIDE_PORTABLE_MAPLAYER_ID+1
-#define MapGuide_Portable_MapLayer_Selection     MAPGUIDE_PORTABLE_MAPLAYER_ID+2
-#define MapGuide_Portable_MapLayer_Controller    MAPGUIDE_PORTABLE_MAPLAYER_ID+3
-#define MapGuide_Portable_MapLayer_AdvController MAPGUIDE_PORTABLE_MAPLAYER_ID+4
-#define MapGuide_Portable_MapLayer_ZcvController MAPGUIDE_PORTABLE_MAPLAYER_ID+5
+#define Portable_MapLayer_Map           PORTABLE_MAPLAYER_ID+0
+#define Portable_MapLayer_Layer         PORTABLE_MAPLAYER_ID+1
+#define Portable_MapLayer_Selection     PORTABLE_MAPLAYER_ID+2
 
 // MapGuide Exceptions
-#define MapGuide_Portable_Exception_AuthenticationFailedException              MAPGUIDE_PORTABLE_EXCEPTION_ID+0
-#define MapGuide_Portable_Exception_ConnectionFailedException                  MAPGUIDE_PORTABLE_EXCEPTION_ID+1
-#define MapGuide_Portable_Exception_ConnectionNotOpenException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+2
-#define MapGuide_Portable_Exception_DbException                                MAPGUIDE_PORTABLE_EXCEPTION_ID+3
-#define MapGuide_Portable_Exception_DbXmlException                             MAPGUIDE_PORTABLE_EXCEPTION_ID+4
-#define MapGuide_Portable_Exception_DuplicateGroupException                    MAPGUIDE_PORTABLE_EXCEPTION_ID+5
-#define MapGuide_Portable_Exception_DuplicateNameException                     MAPGUIDE_PORTABLE_EXCEPTION_ID+6
-#define MapGuide_Portable_Exception_DuplicateParameterException                MAPGUIDE_PORTABLE_EXCEPTION_ID+7
-#define MapGuide_Portable_Exception_DuplicateRepositoryException               MAPGUIDE_PORTABLE_EXCEPTION_ID+8
-#define MapGuide_Portable_Exception_DuplicateRoleException                     MAPGUIDE_PORTABLE_EXCEPTION_ID+9
-#define MapGuide_Portable_Exception_DuplicateServerException                   MAPGUIDE_PORTABLE_EXCEPTION_ID+10
-#define MapGuide_Portable_Exception_DuplicateSessionException                  MAPGUIDE_PORTABLE_EXCEPTION_ID+11
-#define MapGuide_Portable_Exception_DuplicateUserException                     MAPGUIDE_PORTABLE_EXCEPTION_ID+12
-#define MapGuide_Portable_Exception_DwfException                               MAPGUIDE_PORTABLE_EXCEPTION_ID+13
-#define MapGuide_Portable_Exception_DwfSectionNotFoundException                MAPGUIDE_PORTABLE_EXCEPTION_ID+14
-#define MapGuide_Portable_Exception_DwfSectionResourceNotFoundException        MAPGUIDE_PORTABLE_EXCEPTION_ID+15
-#define MapGuide_Portable_Exception_EndOfStreamException                       MAPGUIDE_PORTABLE_EXCEPTION_ID+16
-#define MapGuide_Portable_Exception_EvaluationExpiredException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+17
-#define MapGuide_Portable_Exception_GroupNotFoundException                     MAPGUIDE_PORTABLE_EXCEPTION_ID+18
-#define MapGuide_Portable_Exception_InvalidDwfPackageException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+19
-#define MapGuide_Portable_Exception_InvalidDwfSectionException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+20
-#define MapGuide_Portable_Exception_InvalidFeatureSourceException              MAPGUIDE_PORTABLE_EXCEPTION_ID+21
-#define MapGuide_Portable_Exception_InvalidIpAddressException                  MAPGUIDE_PORTABLE_EXCEPTION_ID+22
-#define MapGuide_Portable_Exception_InvalidLicenseException                    MAPGUIDE_PORTABLE_EXCEPTION_ID+23
-#define MapGuide_Portable_Exception_InvalidLogEntryException                   MAPGUIDE_PORTABLE_EXCEPTION_ID+24
-#define MapGuide_Portable_Exception_InvalidOperationVersionException           MAPGUIDE_PORTABLE_EXCEPTION_ID+25
-#define MapGuide_Portable_Exception_InvalidPasswordException                   MAPGUIDE_PORTABLE_EXCEPTION_ID+26
-#define MapGuide_Portable_Exception_InvalidPrintLayoutFontSizeUnitsException   MAPGUIDE_PORTABLE_EXCEPTION_ID+27
-#define MapGuide_Portable_Exception_InvalidPrintLayoutPositionUnitsException   MAPGUIDE_PORTABLE_EXCEPTION_ID+28
-#define MapGuide_Portable_Exception_InvalidPrintLayoutSizeUnitsException       MAPGUIDE_PORTABLE_EXCEPTION_ID+29
-#define MapGuide_Portable_Exception_InvalidSerialNumberException               MAPGUIDE_PORTABLE_EXCEPTION_ID+30
-#define MapGuide_Portable_Exception_InvalidServerNameException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+31
-#define MapGuide_Portable_Exception_LicenseException                           MAPGUIDE_PORTABLE_EXCEPTION_ID+32
-#define MapGuide_Portable_Exception_LicenseExpiredException                    MAPGUIDE_PORTABLE_EXCEPTION_ID+33
-#define MapGuide_Portable_Exception_LogOpenFailedException                     MAPGUIDE_PORTABLE_EXCEPTION_ID+34
-#define MapGuide_Portable_Exception_OperationProcessingException               MAPGUIDE_PORTABLE_EXCEPTION_ID+35
-#define MapGuide_Portable_Exception_ParameterNotFoundException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+36
-#define MapGuide_Portable_Exception_PathTooLongException                       MAPGUIDE_PORTABLE_EXCEPTION_ID+37
-#define MapGuide_Portable_Exception_PermissionDeniedException                  MAPGUIDE_PORTABLE_EXCEPTION_ID+38
-#define MapGuide_Portable_Exception_PortNotAvailableException                  MAPGUIDE_PORTABLE_EXCEPTION_ID+39
-#define MapGuide_Portable_Exception_PrintToScaleModeNotSelectedException       MAPGUIDE_PORTABLE_EXCEPTION_ID+40
-#define MapGuide_Portable_Exception_RepositoryCreationFailedException          MAPGUIDE_PORTABLE_EXCEPTION_ID+41
-#define MapGuide_Portable_Exception_RepositoryNotFoundException                MAPGUIDE_PORTABLE_EXCEPTION_ID+42
-#define MapGuide_Portable_Exception_RepositoryNotOpenException                 MAPGUIDE_PORTABLE_EXCEPTION_ID+43
-#define MapGuide_Portable_Exception_RepositoryOpenFailedException              MAPGUIDE_PORTABLE_EXCEPTION_ID+44
-#define MapGuide_Portable_Exception_RoleNotFoundException                      MAPGUIDE_PORTABLE_EXCEPTION_ID+45
-#define MapGuide_Portable_Exception_ServerNotFoundException                    MAPGUIDE_PORTABLE_EXCEPTION_ID+46
-#define MapGuide_Portable_Exception_ServerNotOnlineException                   MAPGUIDE_PORTABLE_EXCEPTION_ID+47
-#define MapGuide_Portable_Exception_SessionExpiredException                    MAPGUIDE_PORTABLE_EXCEPTION_ID+48
-#define MapGuide_Portable_Exception_UnauthorizedAccessException                MAPGUIDE_PORTABLE_EXCEPTION_ID+49
-#define MapGuide_Portable_Exception_UriFormatException                         MAPGUIDE_PORTABLE_EXCEPTION_ID+50
-#define MapGuide_Portable_Exception_StylizeLayerFailedException                MAPGUIDE_PORTABLE_EXCEPTION_ID+51
-#define MapGuide_Portable_Exception_SessionNotFoundException                   MAPGUIDE_PORTABLE_EXCEPTION_ID+52
-#define MapGuide_Portable_Exception_UnsupportedProviderThreadModelException    MAPGUIDE_PORTABLE_EXCEPTION_ID+53
-#define MapGuide_Portable_Exception_AllProviderConnectionsUsedException        MAPGUIDE_PORTABLE_EXCEPTION_ID+54
-#define MapGuide_Portable_Exception_RasterTransformationNotSupportedException  MAPGUIDE_PORTABLE_EXCEPTION_ID+55
-#define MapGuide_Portable_Exception_AliasNotFoundException                     MAPGUIDE_PORTABLE_EXCEPTION_ID+56
+//
+// NOTE: Although we removed these exceptions, we are keeping the ids in to prevent these ids from being
+// accidentally used for new classes in the future
+#define UNUSED_MapGuide_Portable_Exception_AuthenticationFailedException              PORTABLE_EXCEPTION_ID+0
+#define UNUSED_MapGuide_Portable_Exception_ConnectionFailedException                  PORTABLE_EXCEPTION_ID+1
+#define UNUSED_MapGuide_Portable_Exception_ConnectionNotOpenException                 PORTABLE_EXCEPTION_ID+2
+#define UNUSED_MapGuide_Portable_Exception_DbException                                PORTABLE_EXCEPTION_ID+3
+#define UNUSED_MapGuide_Portable_Exception_DbXmlException                             PORTABLE_EXCEPTION_ID+4
+#define UNUSED_MapGuide_Portable_Exception_DuplicateGroupException                    PORTABLE_EXCEPTION_ID+5
+#define UNUSED_MapGuide_Portable_Exception_DuplicateNameException                     PORTABLE_EXCEPTION_ID+6
+#define UNUSED_MapGuide_Portable_Exception_DuplicateParameterException                PORTABLE_EXCEPTION_ID+7
+#define UNUSED_MapGuide_Portable_Exception_DuplicateRepositoryException               PORTABLE_EXCEPTION_ID+8
+#define UNUSED_MapGuide_Portable_Exception_DuplicateRoleException                     PORTABLE_EXCEPTION_ID+9
+#define UNUSED_MapGuide_Portable_Exception_DuplicateServerException                   PORTABLE_EXCEPTION_ID+10
+#define UNUSED_MapGuide_Portable_Exception_DuplicateSessionException                  PORTABLE_EXCEPTION_ID+11
+#define UNUSED_MapGuide_Portable_Exception_DuplicateUserException                     PORTABLE_EXCEPTION_ID+12
+#define UNUSED_MapGuide_Portable_Exception_DwfException                               PORTABLE_EXCEPTION_ID+13
+#define UNUSED_MapGuide_Portable_Exception_DwfSectionNotFoundException                PORTABLE_EXCEPTION_ID+14
+#define UNUSED_MapGuide_Portable_Exception_DwfSectionResourceNotFoundException        PORTABLE_EXCEPTION_ID+15
+#define UNUSED_MapGuide_Portable_Exception_EndOfStreamException                       PORTABLE_EXCEPTION_ID+16
+#define UNUSED_MapGuide_Portable_Exception_EvaluationExpiredException                 PORTABLE_EXCEPTION_ID+17
+#define UNUSED_MapGuide_Portable_Exception_GroupNotFoundException                     PORTABLE_EXCEPTION_ID+18
+#define UNUSED_MapGuide_Portable_Exception_InvalidDwfPackageException                 PORTABLE_EXCEPTION_ID+19
+#define UNUSED_MapGuide_Portable_Exception_InvalidDwfSectionException                 PORTABLE_EXCEPTION_ID+20
+#define UNUSED_MapGuide_Portable_Exception_InvalidFeatureSourceException              PORTABLE_EXCEPTION_ID+21
+#define UNUSED_MapGuide_Portable_Exception_InvalidIpAddressException                  PORTABLE_EXCEPTION_ID+22
+#define UNUSED_MapGuide_Portable_Exception_InvalidLicenseException                    PORTABLE_EXCEPTION_ID+23
+#define UNUSED_MapGuide_Portable_Exception_InvalidLogEntryException                   PORTABLE_EXCEPTION_ID+24
+#define UNUSED_MapGuide_Portable_Exception_InvalidOperationVersionException           PORTABLE_EXCEPTION_ID+25
+#define UNUSED_MapGuide_Portable_Exception_InvalidPasswordException                   PORTABLE_EXCEPTION_ID+26
+#define UNUSED_MapGuide_Portable_Exception_InvalidPrintLayoutFontSizeUnitsException   PORTABLE_EXCEPTION_ID+27
+#define UNUSED_MapGuide_Portable_Exception_InvalidPrintLayoutPositionUnitsException   PORTABLE_EXCEPTION_ID+28
+#define UNUSED_MapGuide_Portable_Exception_InvalidPrintLayoutSizeUnitsException       PORTABLE_EXCEPTION_ID+29
+#define UNUSED_MapGuide_Portable_Exception_InvalidSerialNumberException               PORTABLE_EXCEPTION_ID+30
+#define UNUSED_MapGuide_Portable_Exception_InvalidServerNameException                 PORTABLE_EXCEPTION_ID+31
+#define UNUSED_MapGuide_Portable_Exception_LicenseException                           PORTABLE_EXCEPTION_ID+32
+#define UNUSED_MapGuide_Portable_Exception_LicenseExpiredException                    PORTABLE_EXCEPTION_ID+33
+#define UNUSED_MapGuide_Portable_Exception_LogOpenFailedException                     PORTABLE_EXCEPTION_ID+34
+#define UNUSED_MapGuide_Portable_Exception_OperationProcessingException               PORTABLE_EXCEPTION_ID+35
+#define UNUSED_MapGuide_Portable_Exception_ParameterNotFoundException                 PORTABLE_EXCEPTION_ID+36
+#define UNUSED_MapGuide_Portable_Exception_PathTooLongException                       PORTABLE_EXCEPTION_ID+37
+#define UNUSED_MapGuide_Portable_Exception_PermissionDeniedException                  PORTABLE_EXCEPTION_ID+38
+#define UNUSED_MapGuide_Portable_Exception_PortNotAvailableException                  PORTABLE_EXCEPTION_ID+39
+#define UNUSED_MapGuide_Portable_Exception_PrintToScaleModeNotSelectedException       PORTABLE_EXCEPTION_ID+40
+#define UNUSED_MapGuide_Portable_Exception_RepositoryCreationFailedException          PORTABLE_EXCEPTION_ID+41
+#define UNUSED_MapGuide_Portable_Exception_RepositoryNotFoundException                PORTABLE_EXCEPTION_ID+42
+#define UNUSED_MapGuide_Portable_Exception_RepositoryNotOpenException                 PORTABLE_EXCEPTION_ID+43
+#define UNUSED_MapGuide_Portable_Exception_RepositoryOpenFailedException              PORTABLE_EXCEPTION_ID+44
+#define UNUSED_MapGuide_Portable_Exception_RoleNotFoundException                      PORTABLE_EXCEPTION_ID+45
+#define UNUSED_MapGuide_Portable_Exception_ServerNotFoundException                    PORTABLE_EXCEPTION_ID+46
+#define UNUSED_MapGuide_Portable_Exception_ServerNotOnlineException                   PORTABLE_EXCEPTION_ID+47
+#define UNUSED_MapGuide_Portable_Exception_SessionExpiredException                    PORTABLE_EXCEPTION_ID+48
+#define UNUSED_MapGuide_Portable_Exception_UnauthorizedAccessException                PORTABLE_EXCEPTION_ID+49
+#define UNUSED_MapGuide_Portable_Exception_UriFormatException                         PORTABLE_EXCEPTION_ID+50
+#define UNUSED_MapGuide_Portable_Exception_StylizeLayerFailedException                PORTABLE_EXCEPTION_ID+51
+#define UNUSED_MapGuide_Portable_Exception_SessionNotFoundException                   PORTABLE_EXCEPTION_ID+52
+#define UNUSED_MapGuide_Portable_Exception_UnsupportedProviderThreadModelException    PORTABLE_EXCEPTION_ID+53
+#define UNUSED_MapGuide_Portable_Exception_AllProviderConnectionsUsedException        PORTABLE_EXCEPTION_ID+54
+#define UNUSED_MapGuide_Portable_Exception_RasterTransformationNotSupportedException  PORTABLE_EXCEPTION_ID+55
+#define UNUSED_MapGuide_Portable_Exception_AliasNotFoundException                     PORTABLE_EXCEPTION_ID+56
 
 
-//Basic Service functionality
-#define MapGuide_Portable_ServiceFactory                         MAPGUIDE_PORTABLE_SERVICE_ID+0
-//#define MapGuide_Portable_Service_ServerConnection               MAPGUIDE_PORTABLE_SERVICE_ID+0
-//#define MapGuide_Portable_Service_SiteConnection                 MAPGUIDE_PORTABLE_SERVICE_ID+1
-//#define MapGuide_Portable_Service_ConnectionProperties           MAPGUIDE_PORTABLE_SERVICE_ID+2
-//#define MapGuide_Portable_Service_ServerInformation              MAPGUIDE_PORTABLE_SERVICE_ID+3
-//#define MapGuide_Portable_Service_PackageStatusInformation       MAPGUIDE_PORTABLE_SERVICE_ID+4
-//#define MapGuide_Portable_Service_Site                           MAPGUIDE_PORTABLE_SERVICE_ID+5
-//#define MapGuide_Portable_Service_UserInformation                MAPGUIDE_PORTABLE_SERVICE_ID+6
-//#define MapGuide_Portable_Service_ServerAdmin                    MAPGUIDE_PORTABLE_SERVICE_ID+7
-//#define MapGuide_Portable_Service_SiteInfo                       MAPGUIDE_PORTABLE_SERVICE_ID+8
-//#define MapGuide_Portable_Service_SqlResult                      MAPGUIDE_PORTABLE_SERVICE_ID+9
+// Basic Service functionality
+#define Portable_Services_ServiceFactory                         PORTABLE_SERVICE_ID+0
 
-#define MapGuide_Portable_FeatureService_FeatureService              MAPGUIDE_PORTABLE_FEATURESERVICE_ID+0
+// Feature Service
+#define Portable_FeatureService_FeatureService              PORTABLE_FEATURESERVICE_ID+0
 
 // Drawing Service
-#define MapGuide_Portable_DrawingService_DrawingService          MAPGUIDE_PORTABLE_DRAWINGSERVICE_ID+0
+#define Portable_DrawingService_DrawingService          PORTABLE_DRAWINGSERVICE_ID+0
 
 // Mapping Service
-#define MapGuide_Portable_MappingService_MappingService                      MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+0
-#define MapGuide_Portable_MappingService_DwfVersion                          MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+1
-#define MapGuide_Portable_MappingService_PlotSpecification                   MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+2
-#define MapGuide_Portable_MappingService_PrintLayout                         MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+3
-#define MapGuide_Portable_MappingService_Layout                              MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+4
-#define MapGuide_Portable_MappingService_MapPlot                             MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+5
-#define MapGuide_Portable_MappingService_MapPlotCollection                   MAPGUIDE_PORTABLE_MAPPINGSERVICE_ID+6
+#define Portable_MappingService_MappingService                      PORTABLE_MAPPINGSERVICE_ID+0
+#define Portable_MappingService_DwfVersion                          PORTABLE_MAPPINGSERVICE_ID+1
+#define Portable_MappingService_PlotSpecification                   PORTABLE_MAPPINGSERVICE_ID+2
+#define Portable_MappingService_PrintLayout                         PORTABLE_MAPPINGSERVICE_ID+3
+#define Portable_MappingService_Layout                              PORTABLE_MAPPINGSERVICE_ID+4
+#define Portable_MappingService_MapPlot                             PORTABLE_MAPPINGSERVICE_ID+5
+#define Portable_MappingService_MapPlotCollection                   PORTABLE_MAPPINGSERVICE_ID+6
 
 // Rendering Service
-#define MapGuide_Portable_RenderingService_RenderingService                  MAPGUIDE_PORTABLE_RENDERINGSERVICE_ID+0
-#define MapGuide_Portable_RenderingService_FeatureInformation                MAPGUIDE_PORTABLE_RENDERINGSERVICE_ID+1
-#define MapGuide_Portable_RenderingService_RenderingOptions                  MAPGUIDE_PORTABLE_RENDERINGSERVICE_ID+2
+#define Portable_RenderingService_RenderingService                  PORTABLE_RENDERINGSERVICE_ID+0
+#define Portable_RenderingService_FeatureInformation                PORTABLE_RENDERINGSERVICE_ID+1
+#define Portable_RenderingService_RenderingOptions                  PORTABLE_RENDERINGSERVICE_ID+2
 
 // Resource Service
-#define MapGuide_Portable_ResourceService_ResourceService                    MAPGUIDE_PORTABLE_RESOURCESERVICE_ID+0
+#define Portable_ResourceService_ResourceService                    PORTABLE_RESOURCESERVICE_ID+0
 
 
 // Tile Service
-#define MapGuide_Portable_TileService_TileService                            MAPGUIDE_PORTABLE_TILESERVICE_ID+0
+#define Portable_TileService_TileService                            PORTABLE_TILESERVICE_ID+0
 
 // KML Service
-#define MapGuide_Portable_KmlService_KmlService                              MAPGUIDE_PORTABLE_KMLSERVICE_ID+0
+#define Portable_KmlService_KmlService                              PORTABLE_KMLSERVICE_ID+0
 
 // Profiling
-#define MapGuide_Portable_ProfilingService_ProfilingService					MAPGUIDE_PORTABLE_PROFILING_SERVICE_ID+0
+#define Portable_ProfilingService_ProfilingService					PORTABLE_PROFILING_SERVICE_ID+0
 
 #endif
\ No newline at end of file

Modified: trunk/MgDev/Portable/MgPortable/System/PlatformInit.cpp
===================================================================
--- trunk/MgDev/Portable/MgPortable/System/PlatformInit.cpp	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Portable/MgPortable/System/PlatformInit.cpp	2022-11-20 04:09:40 UTC (rev 10019)
@@ -249,9 +249,9 @@
     MgClassFactory* fact = MgClassFactory::GetInstance();
 
     //put in the map any class that can be serialized
-    fact->Register(MapGuide_Portable_MapLayer_Map, MgPortableMap::CreateObject);
-    fact->Register(MapGuide_Portable_MapLayer_Layer, MgPortableLayer::CreateObject);
-    fact->Register(MapGuide_Portable_MapLayer_Selection, MgPortableSelection::CreateObject);
+    fact->Register(Portable_MapLayer_Map, MgPortableMap::CreateObject);
+    fact->Register(Portable_MapLayer_Layer, MgPortableLayer::CreateObject);
+    fact->Register(Portable_MapLayer_Selection, MgPortableSelection::CreateObject);
 
     return true;
 }
\ No newline at end of file



More information about the mapguide-commits mailing list
--- trunk/MgDev/Bindings/src/Tools/ClassMapGen/Program.cs	2022-11-16 14:57:45 UTC (rev 10018)
+++ trunk/MgDev/Bindings/src/Tools/ClassMapGen/Program.cs	2022-11-20 04:09:40 UTC (rev 10019)
@@ -8,6 +8,7 @@
 using System.Xml;
 using NCalc;
 using System.Collections.Concurrent;
+using System.Runtime.InteropServices;
 
 namespace ClassMapGen
 {
@@ -58,15 +59,32 @@
 
             MasterClassMap clsMap = ReadFromSwigXml(opts.SwigXmlFile);
 
-            var classMapMaster = new Dictionary<int, string>();
-            var classMapMasterReverse = new SortedDictionary<string, int>();
+            var classMapMaster = new Dictionary<int, (string name, bool isCoreApi)>();
+            var classMapMasterReverse = new SortedDictionary<string, (int classId, bool isCoreApi)>();
             var addedStats = new ConcurrentDictionary<string, int>();
 
             foreach (var mod in clsMap.Modules)
             {
+                bool isCoreApi = false;
+                switch (mod.Name)
+                {
+                    case "Foundation":
+                    case "Geometry":
+                    case "PlatformBase":
+                    case "MapGuideCommon":
+                    case "Web":
+                        isCoreApi = true;
+                        break;
+                    case "Portable":
+                        isCoreApi = false;
+                        break;
+                    default:
+                        throw new ArgumentException("Unknown module: " + mod.Name);
+                }
+
                 foreach (var kvp in mod.Classes)
                 {
-                    if (classMapMaster.TryAdd(kvp.Key, kvp.Value))
+                    if (classMapMaster.TryAdd(kvp.Key, (kvp.Value, isCoreApi)))
                         addedStats.AddOrUpdate(mod.Name, k => 1, (k, cv) => cv + 1);
                 }
             }
@@ -74,7 +92,7 @@
             //Now populate reverse map
             foreach (var kvp in classMapMaster)
             {
-                classMapMasterReverse[kvp.Value] = kvp.Key;
+                classMapMasterReverse[kvp.Value.name] = (kvp.Key, kvp.Value.isCoreApi);
             }
 
             foreach (var kvp in addedStats)
@@ -92,7 +110,10 @@
             //PHP
             foreach (var kvp in classMapMasterReverse)
             {
-                phpClassMaps.AppendLine($"{PHP_INDENT}classNameMap[{kvp.Value}] = \"_p_{kvp.Key}\";");
+                var (clsId, isCore) = kvp.Value;
+                if (!isCore)
+                    continue;
+                phpClassMaps.AppendLine($"{PHP_INDENT}classNameMap[{clsId}] = \"_p_{kvp.Key}\";");
             }
 
             phpTpl.Replace("$CLASS_NAME_MAP_BODY$", phpClassMaps.ToString());
@@ -102,7 +123,10 @@
             //Java
             foreach (var kvp in classMapMasterReverse)
             {
-                javaClassMaps.AppendLine($"{JAVA_INDENT}classMap.put(new Integer({kvp.Value}), getSWIGCtor(\"{kvp.Key}\"));");
+                var (clsId, isCore) = kvp.Value;
+                if (!isCore)
+                    continue;
+                javaClassMaps.AppendLine($"{JAVA_INDENT}classMap.put(new Integer({clsId}), getSWIGCtor(\"{kvp.Key}\"));");
             }
 
             javaTpl.Replace("$CLASS_NAME_MAP_BODY$", javaClassMaps.ToString());
@@ -112,6 +136,12 @@
             //.net
             foreach (var mod in clsMap.Modules)
             {
+                // Put an ifdef guard around the portable API
+                if (mod.Name == "Portable")
+                {
+                    dotNetClassMaps.AppendLine("#if MG_PORTABLE_API");
+                }
+
                 dotNetClassMaps.AppendLine($"{DOTNET_INDENT}if (HasAssemblyInAppDomain(\"OSGeo.MapGuide.{mod.Name}\")) {{");
 
                 foreach (var kvp in mod.Classes)
@@ -120,6 +150,11 @@
                 }
 
                 dotNetClassMaps.AppendLine($"{DOTNET_INDENT}}}");
+
+                if (mod.Name == "Portable")
+                {
+                    dotNetClassMaps.AppendLine("#endif");
+                }
             }
 
             dotNetTpl.Replace("$CLASS_NAME_MAP_BODY$", dotNetClassMaps.ToString());
@@ -165,6 +200,11 @@
                 Name = "Web",
                 Classes = new Dictionary<int, string>()
             };
+            var modPortable = new ModuleDef
+            {
+                Name = "Portable",
+                Classes = new Dictionary<int, string>()
+            };
 
             var modsByName = new Dictionary<string, ModuleDef>
             {
@@ -172,7 +212,8 @@
                 { modGeometry.Name, modGeometry },
                 { modPlatformBase.Name, modPlatformBase },
                 { modMapGuideCommon.Name, modMapGuideCommon },
-                { modWeb.Name, modWeb }
+                { modWeb.Name, modWeb },
+                { modPortable.Name, modPortable }
             };
 
             var clsMap = new MasterClassMap
@@ -183,7 +224,8 @@
                     modGeometry,
                     modPlatformBase,
                     modMapGuideCommon,
-                    modWeb
+                    modWeb,
+                    modPortable
                 }
             };
 
@@ -227,9 +269,29 @@
                             var mod = modsByName[modName];
                             var className = uqClassName;
 
-                            //Prefix "Mg" if not done already
-                            if (!className.StartsWith("Mg"))
-                                className = "Mg" + uqClassName;
+                            switch (modName)
+                            {
+                                case "Foundation":
+                                case "Geometry":
+                                case "PlatformBase":
+                                case "MapGuideCommon":
+                                case "Web":
+                                    {
+                                        //Prefix "Mg" if not done already
+                                        if (!className.StartsWith("Mg"))
+                                            className = "Mg" + uqClassName;
+                                    }
+                                    break;
+                                case "Portable":
+                                    {
+                                        //Prefix "MgPortable" if not done already
+                                        if (!className.StartsWith("MgPortable"))
+                                            className = "MgPortable" + uqClassName;
+                                    }
+                                    break;
+                                default:
+                                    throw new ArgumentException("Unknown module: " + modName);
+                            }
 
                             // Skip class ids for removed exception classes. The ids are remaining in the
                             // original headers so we don't try to reuse them for any new classes we add to the 

Modified: trunk/MgDev/Bindings/src/Tools/ClassMapGen/classids.i
===================================================================